summaryrefslogtreecommitdiffstats
path: root/libkcal/icalformat.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkcal/icalformat.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkcal/icalformat.cpp')
-rw-r--r--libkcal/icalformat.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/libkcal/icalformat.cpp b/libkcal/icalformat.cpp
index 76898ec09..8c1cd3b0b 100644
--- a/libkcal/icalformat.cpp
+++ b/libkcal/icalformat.cpp
@@ -267,7 +267,7 @@ TQString ICalFormat::toString( Calendar *cal )
if (!text) {
setException(new ErrorFormat(ErrorFormat::SaveError,
i18n("libical error")));
- return TQString::null;
+ return TQString();
}
return text;
@@ -298,15 +298,15 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
icalcomponent *component;
TQString text = "";
// See if there are any parent or child events that must be added to the string
if ( incidence->hasRecurrenceID() ) {
- // Get the parent
+ // Get the tqparent
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
it = il.begin();
- Incidence *parentIncidence;
- parentIncidence = calendar->incidence(*it);
- il = parentIncidence->childIncidences();
+ Incidence *tqparentIncidence;
+ tqparentIncidence = calendar->incidence(*it);
+ il = tqparentIncidence->childIncidences();
if (il.count() > 0) {
for ( it = il.begin(); it != il.end(); ++it ) {
component = mImpl->writeIncidence( calendar->incidence(*it) );
@@ -314,12 +314,12 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
icalcomponent_free( component );
}
}
- component = mImpl->writeIncidence( parentIncidence );
+ component = mImpl->writeIncidence( tqparentIncidence );
text = text + TQString::fromUtf8( icalcomponent_as_ical_string( component ) );
icalcomponent_free( component );
}
else {
// This incidence is a potential parent
IncidenceList il = incidence->childIncidences();
if (il.count() > 0) {
IncidenceListIterator it;
@@ -377,7 +377,7 @@ TQString ICalFormat::createScheduleMessage(IncidenceBase *incidence,
// We have a separation of scheduling ID and UID
i = i->clone();
i->setUid( i->schedulingID() );
- i->setSchedulingID( TQString::null );
+ i->setSchedulingID( TQString() );
// Build the message with the cloned incidence
message = mImpl->createScheduleComponent( i, method );
@@ -577,7 +577,7 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
kdDebug(5800) << "ICalFormat::parseScheduleMessage() returning..." << endl;
kdDebug(5800) << "ICalFormat::parseScheduleMessage(), result = " << result << endl;
- ScheduleMessage::Status status;
+ ScheduleMessage::tqStatus status;
switch (result) {
case ICAL_XLICCLASS_PUBLISHNEW:
@@ -298,15 +298,15 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
icalcomponent *component;
TQString text = "";
- // See if there are any parent or child events that must be added to the string
+ // See if there are any tqparent or child events that must be added to the string
if ( incidence->hasRecurrenceID() ) {
@@ -314,12 +314,12 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
}
else {
- // This incidence is a potential parent
+ // This incidence is a potential tqparent
IncidenceList il = incidence->childIncidences();
if (il.count() > 0) {